"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.formatReposDiffsForChoices = formatReposDiffsForChoices;

var _chalk = _interopRequireDefault(require("chalk"));

var _lodash = _interopRequireDefault(require("lodash"));

var _fp = _interopRequireDefault(require("lodash/fp"));

var _humanDate = require("human-date");

var _longest = _interopRequireDefault(require("longest"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/* eslint-disable camelcase */
function formatReposDiffsForChoices(diffs) {
  return filterAndSortDiffs(diffs).map(diff => formatRepoDiff(diffs, diff));
}

function formatRepoDiff(diffs, diff) {
  const {
    behind_by,
    ahead_by,
    lastCommitDateFormatted,
    repo,
    lastRelease,
    lastDraftReleaseTag
  } = diff;
  const widestDateLength = getWidestProperty(diffs, 'lastCommitDateFormatted');
  const widestRepoLength = getWidestProperty(diffs, 'repo');
  const behind = formatBehindBy(behind_by);
  const ahead = formatAheadBy(ahead_by);
  const repoFmt = (0, _chalk.default)`{bold ${_lodash.default.padEnd(repo, widestRepoLength)}}`;
  const release = (0, _chalk.default)`{dim ${_lodash.default.padEnd(lastRelease, 8)}}`;
  const releaseDraft = (0, _chalk.default)`{dim ${_lodash.default.padEnd(lastDraftReleaseTag, 8)}}`;
  const date = (0, _chalk.default)`{dim ${_lodash.default.padEnd(lastCommitDateFormatted, widestDateLength)}}`;
  return {
    name: (0, _chalk.default)`${behind} ${ahead} ${repoFmt} ${release} ${releaseDraft} ${date}`,
    value: repo
  };
}

function filterAndSortDiffs(diffs) {
  return _fp.default.flow(_fp.default.reject({
    status: 'no-branch'
  }), _fp.default.reject({
    ahead_by: 0,
    behind_by: 0
  }), _fp.default.orderBy([d => new Date(d.lastCommitDate)], ['asc']), _fp.default.map(d => _lodash.default.set(d, 'lastCommitDateFormatted', formatDate(d.lastCommitDate))))(diffs);
}

function getWidestProperty(diffs, property) {
  return _fp.default.flow(_fp.default.map(property), _fp.default.compact, _longest.default, _fp.default.size)(diffs);
}

function formatBehindBy(behindBy) {
  if (behindBy === 0) {
    return (0, _chalk.default)`{red.dim ${_lodash.default.padStart(`${behindBy}`, 4)}}`;
  }

  return (0, _chalk.default)`{red ${_lodash.default.padStart(`-${behindBy}`, 4)}}`;
}

function formatAheadBy(aheadBy) {
  if (aheadBy === 0) {
    return (0, _chalk.default)`{green.dim ${_lodash.default.padEnd(`${aheadBy}`, 5)}}`;
  }

  return (0, _chalk.default)`{green ${_lodash.default.padEnd(`+${aheadBy}`, 5)}}`;
}

function formatDate(date) {
  return (0, _humanDate.relativeTime)(new Date(date));
}