"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.askNewReleaseVersion = askNewReleaseVersion;
exports.askReleaseTitle = askReleaseTitle;
exports.askToOpenPR = askToOpenPR;

var _inquirer = _interopRequireDefault(require("inquirer"));

var _chalk = _interopRequireDefault(require("chalk"));

var _normalizeSpaceX = require("normalize-space-x");

var _opn = _interopRequireDefault(require("opn"));

var _clientReleases = require("../client-releases");

var _semver = require("../semver");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

async function askNewReleaseVersion({
  org,
  repo
}) {
  const lastRelease = await (0, _clientReleases.getLastRelease)({
    org,
    repo
  });
  const {
    version
  } = await _inquirer.default.prompt([{
    type: 'list',
    name: 'version',
    message: 'Version?',
    choices: (0, _semver.getNextVersionOptions)(lastRelease)
  }]);
  return version;
}

async function askReleaseTitle({
  org,
  repo
}) {
  const {
    inputType
  } = await _inquirer.default.prompt([{
    type: 'list',
    name: 'inputType',
    message: 'Release Title?',
    choices: [{
      name: 'Enter now',
      value: 'enter-now'
    }, {
      name: (0, _chalk.default)`Enter after comparing branches {dim (opens github in browser)}`,
      value: 'enter-after'
    }]
  }]);

  if (inputType === 'enter-after') {
    const compareURL = `https://github.com/${org}/${repo}/compare/master...develop#commits_bucket`;
    (0, _opn.default)(compareURL);
  }

  const {
    releaseTitle
  } = await _inquirer.default.prompt([{
    type: 'input',
    name: 'releaseTitle',
    message: 'Release Title?',
    default: '...',

    filter(input) {
      return (0, _normalizeSpaceX.normalizeSpace)(input);
    },

    validate(input = '') {
      input = (0, _normalizeSpaceX.normalizeSpace)(input);

      if (input.length < 6) {
        return 'Please enter at least 6 letters';
      }

      return true;
    }

  }]);
  return releaseTitle;
}

async function askToOpenPR({
  org,
  repo,
  pr
}) {
  const {
    shouldOpenPR
  } = await _inquirer.default.prompt([{
    type: 'confirm',
    name: 'shouldOpenPR',
    message: 'Open PR in Browser?',
    default: true
  }]);

  if (shouldOpenPR) {
    const prURL = `https://github.com/${org}/${repo}/pull/${pr}`;
    (0, _opn.default)(prURL);
  }
}