"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.askDraftReleasePRNumber = askDraftReleasePRNumber;
exports.askDraftReleaseVersion = askDraftReleaseVersion;

var _ora = _interopRequireDefault(require("ora"));

var _inquirer = _interopRequireDefault(require("inquirer"));

var _logSymbols = _interopRequireDefault(require("log-symbols"));

var _helpers = require("./helpers");

var _clientReleases = require("../client-releases");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

async function askDraftReleaseVersion({
  org,
  repo
}) {
  const tagsSpinner = (0, _ora.default)('Fetching draft releases');
  const draftReleaseTags = await (0, _clientReleases.getDraftReleaseTags)({
    org,
    repo
  });
  tagsSpinner.stop();
  const {
    release
  } = await _inquirer.default.prompt([{
    type: 'list',
    name: 'release',
    message: 'Version?',
    choices: draftReleaseTags.map(release => {
      return {
        name: release.tag,
        value: release
      };
    })
  }]);
  return {
    version: release.tag,
    releaseId: release.id
  };
}

async function askDraftReleasePRNumber({
  org,
  repo,
  version
}) {
  const prsSpinner = (0, _ora.default)('Fetching open PRs');
  const prs = await (0, _clientReleases.getOpenReleasePRs)({
    org,
    repo
  });
  prsSpinner.stop();
  const {
    isReadyToMerge,
    prTitle,
    prNumber,
    reason
  } = (0, _helpers.getOpenReleasePRForVersion)(prs, version);

  if (!isReadyToMerge) {
    console.log(_logSymbols.default.error, reason);
    return process.exit(0);
  }

  const {
    confirm
  } = await _inquirer.default.prompt([{
    type: 'confirm',
    name: 'confirm',
    message: prTitle
  }]);

  if (!confirm) {
    console.log(_logSymbols.default.info, 'Release aborted. No changes have been made');
    return process.exit(0);
  }

  return prNumber;
}