"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.verifyToken = verifyToken;

var _boxen = _interopRequireDefault(require("boxen"));

var _path = _interopRequireDefault(require("path"));

var _debug = _interopRequireDefault(require("debug"));

var _package = require("../package.json");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const debug = (0, _debug.default)(`${_package.name}:${_path.default.basename(__filename)}`);

function verifyToken() {
  const {
    GITHUB_TOKEN
  } = process.env;

  if (GITHUB_TOKEN && GITHUB_TOKEN.length === 40) {
    return debug('[ok] GITHUB_TOKEN found in process.env');
  }

  debug('No GITHUB_TOKEN was found');
  console.log((0, _boxen.default)(`
    To use this CLI you need to set GITHUB_TOKEN as environment variable

    Follow the steps:

    - Go to https://github.com/settings/tokens/new?scopes=admin:org,repo&description=gh-shipit-cli
    - Click "Generate Token"
    - echo "export GITHUB_TOKEN=XXXXX" >> ~/.bashrc
  `.trim(), {
    align: 'left',
    float: 'center',
    borderColor: 'magenta',
    padding: 1
  }));
  return process.exit(0);
}